#pragma rtGlobals=1		// Use modern global access method and strict wave access.
#pragma hide=1

//////////////////////////////////////////////////////////////////////////////////
//Licence
//////////////////////////////////////////////////////////////////////////////////
//
//	If you use the 'Fit Assistant' to analyze data, please read and cite the following paper:
//	Surace and Interface Analysis, (2014), 46, 505-511
//	This publication contains more details on the fit function used by XPST.
//
//	XPST is a front-end to the IgorPro fitting engine. Although every possible effort was made 
//	to prevent serious bugs and wrong results, the author can not give any warranty for XPST as 
//	large parts actually depend on the underlying IgorPro code. 
//	Author: Dr. Martin Schmid
//
//////////////////////////////////////////////////////////////////////////////////

menu "XPST"
	"Thickness Calculation", LaunchSTThicknessPanel()
end

//this macro blocks repeated opening of the ThicknessPanel, there can be only one instance of
//ThicknessPanel active, otherwise there will be trouble with the global variables

macro LaunchSTThicknessPanel()	
	DoWindow STThicknessPanel   //this will write "1" into V_Flag (a system variable of Igor) if the window is open already
	
	if (V_Flag )
		DoWindow /F STThicknessPanel  // if it is already open, bring it to front
		return -1  //and leave without doing anything else
		
	endif
	
	STThicknessPanel()
end



Window STThicknessPanel() : Panel
	PauseUpdate; Silent 1			// building window...
	NewPanel /K=2 /W=(570,57,995,814) as "."			// /K=2 disables the close button --- import for clean variable handling
	ModifyPanel cbRGB=(65534,65534,65534)
	SetDrawLayer UserBack
	DrawText 27,674,"Be aware that the value for sigma (relative senstivity factor)"
	DrawText 27,690,"can vary between literature and different spectrometers."
	DrawText 27,724,"Use the approximation with caution!"

	DrawPict 14,20,0.756152,0.794224,ProcGlobal#ThicknessGUIBackground
	//place all elements onto the panel
	SetDrawEnv fstyle= 1
	DrawText 103,297,"Intensity"
	SetDrawEnv fstyle= 1,textrgb= (52224,0,0)
	DrawText 40,351,"B"
	SetDrawEnv fstyle= 1
	DrawText 256,296,"# Sweeps"
	SetDrawEnv fstyle= 1,textrgb= (65280,43520,0)
	DrawText 40,323,"A"
	SetDrawEnv fname= "Symbol",fsize= 14,fstyle= 1
	DrawText 85,413,"l"
	SetDrawEnv fname= "Symbol",fsize= 14,fstyle= 1
	DrawText 280,413,"s"
	SetDrawEnv fname= "Symbol",fsize= 14,fstyle= 1
	DrawText 214,570,"q = "
	SetDrawEnv fsize= 19
	DrawText 167,622,"d =    "
	SetDrawEnv fsize= 19
	DrawText 290,620,"nm"
	DrawText 100,412,"[nm]"
	SetDrawEnv fstyle= 1,textrgb= (52224,0,0)
	DrawText 237,351,"B"
	SetDrawEnv fstyle= 1,textrgb= (65280,43520,0)
	DrawText 237,322,"A"
	SetDrawEnv fstyle= 1,textrgb= (52224,0,0)
	DrawText 40,461,"B"
	SetDrawEnv fstyle= 1,textrgb= (65280,43520,0)
	DrawText 40,436,"A"
	SetDrawEnv fstyle= 1,textrgb= (52224,0,0)
	DrawText 231,460,"B"
	SetDrawEnv fstyle= 1,textrgb= (65280,43520,0)
	DrawText 231,437,"A"
	SetDrawEnv fsize= 18,fstyle= 1
	DrawText 208,38,"Thickness Calculation"
	
	GroupBox group0,pos={9,274},size={350,99}
	GroupBox group1,pos={9,375},size={349,158}
	GroupBox group2,pos={163,380},size={190,91}
	GroupBox group3,pos={10,534},size={347,53}
	GroupBox group4,pos={10,588},size={347,54}
	
       ///// Make a datafolder to keep all the global variables
       
       NewDataFolder /o root:thickenss_calc_variables	
       
       ///// Now Introduce the functional elements
   	
   	variable/G root:thickenss_calc_variables:IA_Value= 100
	SetVariable Input_IA,pos={64,308},size={128,16}
	SetVariable Input_IA, limits={0,10000000,0}, value=root:thickenss_calc_variables:IA_Value, title=" "
	
	variable/G root:thickenss_calc_variables:IB_Value= 10000
	SetVariable Input_IB,pos={64,336},size={128,16}
	SetVariable Input_IB, limits={0,10000000,0}, value=root:thickenss_calc_variables:IB_Value, title=" "
	
	variable/G root:thickenss_calc_variables:SweepA_Value= 1
	SetVariable Input_SweepA,pos={256,308},size={65,16}
	SetVariable Input_SweepA, limits={1,1000,1}, value=root:thickenss_calc_variables:SweepA_Value, title=" "
	
	variable/G root:thickenss_calc_variables:SweepB_Value= 1
	SetVariable Input_SweepB,pos={257,336},size={64,16}
	SetVariable Input_SweepB, limits={1,1000,1}, value=root:thickenss_calc_variables:SweepB_Value, title=" "
	
	variable/G root:thickenss_calc_variables:LambdaA_Value= 2.81
	SetVariable Input_LambdaA,pos={64,421},size={80,16}
	SetVariable Input_LambdaA, limits={0,1000,0}, value=root:thickenss_calc_variables:LambdaA_Value, title=" "
	
	variable/G root:thickenss_calc_variables:LambdaB_Value= 3.098
	SetVariable Input_LambdaB,pos={64,446},size={80,16}
	SetVariable Input_LambdaB, limits={0,1000,0}, value=root:thickenss_calc_variables:LambdaB_Value, title=" "
	
	variable/G root:thickenss_calc_variables:SigmaA_Value=0.25
	SetVariable Input_SigmaA,pos={256,421},size={64,16}
	SetVariable Input_SigmaA, limits={0,1000,0}, value=root:thickenss_calc_variables:SigmaA_Value, title=" ", disable = 2
	
	variable/G root:thickenss_calc_variables:SigmaB_Value= 4.95
	SetVariable Input_SigmaB,pos={256,446},size={64,16}
	SetVariable Input_SigmaB, limits={0,1000,0}, value=root:thickenss_calc_variables:SigmaB_Value, title=" ", disable = 2
	
	variable/G root:thickenss_calc_variables:K_Value=0.046
	SetVariable Input_K,pos={42,491},size={208,16}
	SetVariable Input_K, limits={0,1000,0}, value=root:thickenss_calc_variables:K_Value, title="Numerical value for K  "
	
	variable/G root:thickenss_calc_variables:Theta_Value=70
	SetVariable Input_Theta, pos={244,554},size={76,16}
	SetVariable Input_Theta, limits={0,90,1}, value=root:thickenss_calc_variables:Theta_Value, title=" "
	
	Variable /G root:thickenss_calc_variables:Approximate = 0
	CheckBox Check_Approximate,pos={175,389},size={86,14},title="Approximate K"
	CheckBox Check_Approximate,value= 0, proc=ST_ThicknessPanelAppCheck
	
	Variable /G root:thickenss_calc_variables:Thickness_Value
	ValDisplay Output_d,pos={195,604},size={86,14},limits={0,0,0},barmisc={0,1000}
	ValDisplay Output_d,value= #"0"
	
	Button Button_Calc,pos={80,592},size={70,44},title="Calculate", proc=ST_ThicknessPanelCalc
	Button Button_Exit,pos={17, 592},size={60,44},title="EXIT", proc=ST_ThicknessPanelExit
EndMacro



function ST_ThicknessPanelAppCheck(ctrlName,checked): CheckBoxControl
	string ctrlName
	variable checked
	NVAR value = root:thickenss_calc_variables:Approximate
	value = checked
	
	if (checked == 1)
		SetVariable Input_K disable=2
		SetVariable Input_SigmaA disable = 0
		SetVariable Input_SigmaB disable = 0

	else	
		SetVariable Input_K disable=0
		SetVariable Input_SigmaA disable = 2
		SetVariable Input_SigmaB disable = 2
		
	endif
end



function ST_ThicknessPanelExit(ctrlName) : ButtonControl
	string ctrlName
	DoWindow /K STThicknessPanel
	
	/////////////////////////////////////////////////////////////////////////////////
      // alternative: without hard-coding the name of the panel to be killed
      // Let Igor figure out itself, which window to kill
	////////////////////////////////////////////////////////////////////////////////
	// 1. Let Igor find out on which panel the button lives

	//string ObjectNames = WinList("*", ";", "WIN:64")  //get the name of all panels (specified by Win:64)
	//string LastObjectName = StringFromList(0,ObjectNames) //get the name of the top window 
													       //... this should be the ThicknessPanel as the Button which called this function lives there
	
	// 2. And now do DoWindow /K with the name that Igor found, note the usage of 'sprintf'
	//string cmd                                                            // generate a string to carry our command
	//sprintf cmd, "DoWindow /K %s", LastObjectName   //DoWindow can't handle strings as arguments
	//Execute/P cmd                                                    //send this to the command line

	KillDataFolder /Z root:thickenss_calc_variables		
end



function ST_ThicknessPanelCalc(ctrlName) : ButtonControl
	string ctrlName
	
	//reference all the global variables
	
	NVAR IA = root:thickenss_calc_variables:IA_Value
	NVAR IB = root:thickenss_calc_variables:IB_Value
	NVAR SweepA = root:thickenss_calc_variables:SweepA_Value
	NVAR SweepB = root:thickenss_calc_variables:SweepB_Value
	NVAR LambdaA = root:thickenss_calc_variables:LambdaA_Value
	NVAR LambdaB = root:thickenss_calc_variables:LambdaB_Value
	NVAR SigmaA =  root:thickenss_calc_variables:SigmaA_Value
	NVAR SigmaB = root:thickenss_calc_variables:SigmaB_Value
	NVAR K = root:thickenss_calc_variables:K_Value
	NVAR Theta = root:thickenss_calc_variables:Theta_Value 				 // !! Input in Degree, but Igor calculates in Rad
	NVAR ApproxDecide = root:thickenss_calc_variables:Approximate
	NVAR thicknessResult = root:thickenss_calc_variables:Thickness_Value
	
	//define some auxilliary variables for the calculation
	
	variable d  = 0			//this is, where we put our result
	variable constFac
	variable IntRatio
	variable effectiveLambdaA = LambdaA * cos( Theta*pi/180 )
	variable effectiveLambdaB = LambdaB * cos( Theta*pi/180 )
	
	if ( ApproxDecide == 0)
		constFac = K
		
	else
		constFac = ( LambdaA * SigmaA ) / ( LambdaB * SigmaB )
		
	endif
	
	IntRatio = ( IA / SweepA ) / ( IB / SweepB )
	IntRatio /= constFac

	// now extract  d from IntRatio =  ( 1 - exp ( - d / (LambdaA * cos(Theta*pi/180) ) ) ) / exp ( - ( d / LambdaB * cos(Theta*pi/180)) )
	// do this by simply walking up the distance
	// until     IntRatio - ( 1 - exp ( - d / (LambdaA * cos(Theta*pi/180) ) ) ) / exp ( - ( d / LambdaB * cos(Theta*pi/180)) )   = 0.00001
	
	do
		d += 0.00001	
		
	while ( IntRatio - ( 1 - exp ( - d / effectiveLambdaA  ) ) / exp ( - ( d / effectiveLambdaB  ) )  > 0.00001 )
	
	thicknessResult = d
	ValDisplay Output_d,value=#"root:thickenss_calc_variables:Thickness_Value"  			 //Igor requires weird code here, dunno why
end


//this is really not intuitive
//for a picture to ASCII85 converter see:  http://www.webutils.pl/index.php?idx=ascii85 
//  do not copy and paste the <~  and ~>   at the start and end of the ASCII85 string
Picture ThicknessGUIBackground
ASCII85Begin
M,6r;%14!\!!!!.8Ou6I!!!,$!!!'h#R18/!7Vknr;Zft!HV./639EfIDl0d!"!U8=`XQC(
D6]J(D6a]T@-U;!!!mY79FY1De=*8@<,oZ9ke*XDf]i/F<F@kAnbadJ*f+5!!$898OPjDGhVQ
@Deq8bI38/O?76al0Nb(u#S[gU,=!+=72@;G0M#GbK*!3(1h@=JT[h[t+HA]DH9p26^p]*5MW
<,cda5.$d4L#*;.;56%FI(m0T[:CPq%WN/8JNo&T<n9N8QaUl6r`C$(G/Xd<>8p_g;n)B4bfV
cg6$#hui4aL<JD@Zb,B^^GG%0hYZ1(2?3^WTI_&c!!!!%<<*"!&6&Z1!"`*1!!#8\"TSNf:^%
X0VJJ)8+ia]c!'q?%G>K<7*"r;P"B@]`"TSNg'bF=F!'j?a5nsA""B@]`"TSNg'a.M:!"`*15
nsA""B?"4!<>A]"U%g*!"`*q:^$h!5nsr1!<>A]"[Q-b"TUea"U%g*!"`*15nsA""B?"4!<>A
]"c<K6G/uB=!'j?aQnDM0,b]P=nGiPS:^,Df:sVW!U7o`=,KGfT!!%U#Yf_LM*4\Ull07uXPF
q<)oTGi=3E?+[#cb\?K'IIk7aG#AD$<qjF2nXg!'q?%G"=bg6Km@4P+&]&@5&D*jgY<k+K,@b
$E;c)pIP@ubh91&A3U%o&6+4+KBdGQ.IBg]pF<,SRLL)6!'q?%8l32-K'M3GI8>HC9rnHtJ=m
6#4J_C5bKt'$fRH-<GMj;>!$J3AM[l`l@8L6OYQY",5o#bFW1F3eo<,n.bp]OY3K=(>#c^_W:
tQ/@j>gKLU%>_Nmt=""d(';[5Z!1"#1_Zh_e`BkSfaS'YMek3"M]$;g]@HuW.L\RaQF8_pj4s
J/KbJ%kKYXZ!.l[+Wf)7"GJS?HLkd?j#[bW+EshtuTF-;9,+m?O$q#N^f5^*2!WX@AJtT]rkL
>uB18Q5Y('">#'a3&U5,ZT^3SbM(Ik,gcqp$bn!.l[+Wf)7"B@Au@dD)79FmM/u!!!;)+K-p`
3?:N6CO<qtm:cNsF'G.-gDQW5`rZ5P<'a>dp2erVVF!>X-T0Pcn%@5Gh/89Y#>5oE2us!bWZ\
5mrHVZ`SK''s.X^0eDL@r@7-iu=3u7l.<'a>dan'6^?(rZJc:0[6ZeK4s7?%a'%1rgF&6(ql?
,UfrRWP1eGZ_1bC+\.R=r$_XN<url!'q>&eQ"cAh&r5XAaK"j@CpMC2mRj,WhQ(E:&og;$A.Q
CT3j)SX!c<'e&S/uisD*Cc])_0Wi,oJTF-9cq1<>m<pu78plGX-a88afc1nkiD,M)`!"`,'k+
SFg.f"-+=4k*@"'*j1ClbTp!.^^L5\WRM<_teX70NYo<<,W'<qfTk!<>D#J?jmZ$WU.+5YqWW
9L3eo'bp][;ult!&6&Z1!'j?a@.bW>f!tqa"B>Fo'N4[h-"lol%fejk"^ml%FXrlnpMlUhEEM
%;C]FH$'nCF[eAj'(0QQ.I!!%U#^k04DV/c%M<uP/X?DBU1*e$M"0I<C3<Rf[#irf>fW^)\cd
0hr]ksjWRB,";M_cIbo8#-*uMo'7H-On4tU5n&iltJriJ=m5`%2_l-Kk$8b<fb+jRV!7=DdU0
*\/am_;MXa&T$_cC/?aqGemADB:^%!P,oQs7hP@BE&RI+[_=`$m?8nhMlm:1[<E&r`:^%!PF\
*MR4H%TsoW&m:P:Gjs.OkE@VuhQcH,Ajo]KnD"]\^<rB]K$Pj7g]!N?%oO<CI&k"B@]`/YUZ;
^qVaI5OsMjcR^BT[S"nQ[PB1(;FL`h"B@]`?)LP5gjM'`pfBpkN!oeq*Vo(J]RG08iO(TOY@j
Wncrik`9kO0#70NYo<BsA4@9>[<(*pX3"k>F?8bMc,Knn:/d;q>gLZfJ[RgW4q!'j?a"P",'&
']M<*5>Z"XJU^'09(@.jAQEmY(K`0<r`4d'bF>;+E[tZVc&6L:[:F\?9abb/"Su<5.nP;[b'`
'*/nMaFq+NQ"B?"42`%P\2?\8.hakWMh%IWk7iL.-.0(Kh!i6=*UOTD.p.0DgCo!EXV!c9C@7
,RCp"IJgP48>$O\\^o<X0^a$nm+g8U.oj\M!1\3<0&2.b$/N-55JLVf352k'0qZ]91:!cH+;.
+312e!M26_rqa^VZU=$&q]!H/\%R53YMU.5mkkTf7fWNT'du^O4de((G,*)?:>+egWQ]8HUcp
Gecc0D_D@Jlhc!]UVh@-T??YU!FhYHd`D1?>2q!a3XF#OLE!"`+\&d?h'.>-o*oU(glZ8X!u,
?l*%<'SfEIe/gos%-&cfZ<NI,ci>1DApFKh=Pc0r1.a9s7Q?k!!H;p9L6(O<'YfP>+$b[rMj#
/UW;^;%(Hhi4g5k==GORZle)j-:TnI<E+CY9$r9X(cUVXJc&1fM2-bEV!!%U#YcaYq,]k[.EV
GV>^t7%9A2bX4Q>QtI?57U0].ptt?_?/H>5JW3!!#;"f_e!^OA)ek#Gq<[k!fO)&e+l5=@MU6
L(=g:o6VBTpU+3*5YqXL&m2W,qbur=mVcqhJ[VkJ/rcooc\DJ&@0lA@.dD/^n*d-t#lKh0\pk
Os5YqWAL=W-0R[VG/>fe/*aV$HiR;8+;EA^%iE#&'9GOD(ecd?O<dlmd45o&=kDbT.)#HRHRK
[fWDlJm2j?X6q`2(PIdWM5.H`Nu4P+sd4S:^'CAl<-Rkn@G\W".,jA)B)[Ma.Y?!MAl>MM3Iu
?5ntLqX<&_3f#2!>]]@=4a[0`c(%jA`XeNg]]a7]g7k[Q3"9@@&!(FciDD9aA4@=(g"9EX`'M
r^H"6ql<I;/XqVN+qgk#>35-;jmF&6+3p_s5go9hJM.N0h+Y90iGHU\WoENRQ*[^>g^.f?4b(
$iB=(pSZk_IfP"l$BQ9/Ri-"F%TaZOX&;BWg)$?pQ5?_]0"!hB5YqWO**?"g2&l$S<`)5VIWg
5+Yr2ge#c[mD_J1G9p,cC,qPn,,U7Rsj5'-0Z+#eTlV7-(%!!oU?\cZ=n<.V9b\+G2SU+5HqD
.C)bpLY^s4@.E4*oB@X!!%U#PVi;$),a\df?di+81dsZ[FoqRI`BRUgu"Sl#lm4e"[TPtc[@m
C)0diR==nS/270daqAQ=[;??h0<'a>4ht(`H4@EtdDU0"p93t&8[(jAkC9!,T!!!.%&6'JF]F
RoWgso@)[6dmCMi3ioUpT;J!<<D*J=ns\F&-#KVHkUGf!UD3kc:Zr.5edd!!#;"&6.hBrk7MQ
oQ(+LSZA]_hg.2C;W%?P!"`*16$4p.^QfH(N`&5ZYL0Lq'fGXKZ\ao!]H7+R5nsr1(\\inU=V
,k=QtfRXQ-]Sa$D8_MYc#V<DahY*Nc#mC*Fr(!'q>&eWmh&m:Z^^Z-LOSg2$&)o9I=DC-_ama
SfiUlD)1g1#1GbE>:@$8Egj&.00DSWZ\5mqfR"ufC=3::ZJbpX/N5(-_rpEYD9^;.]S>i!!!.
%&6)a-3lY1M624Wdrd),TW+d:of'mlXU]^Z?W.L\R)ZN+0n[BTI8%[:gp3s)j<Rao#OV.YETF
-;9nr<*,rR=V$r_7%?1$jC_gf;k3HTmS?OnSnW+K,?nlCn>pOVrRK<(.g'L3-er5l?VkM3M3#
$NP^M$4*Yi#cT,=d<@\rdWf5s_o%WBeV@f3V[cCr"98_-%K_kHW4#'Y#cIp-W)m&[@AhQkhVB
cmME5'I-4Kd<QR*-A-;jmF&6+2aLXZB*eC2muX.,0dEEUK"4B>>>Wq?".M2)(\5+5%,UQ'?^$
31W:*<]c9J3(Z_W'C'0:P7];Wk.OHlD(bgM`QhnR7IVa5YqXH&#iLaMgBgM1d(3m/AI''2@cp
eSkR6o8cSjC.PPL#rCCFF'Mu!1S^I2jiH^6LpHI,*<`-VJ+sd3h5o!L-8F88qUEK4`l\rQ[f$
c<5Slf\E<Re^q2,mGf54Y-&=A8=qT228)UTFOs#cb\9JGOR,ofBF:qY=UdU5n\8%0P_fq-pD'
c0">U2QaWLqPB=87A7EY3jI!Y;EE:h!!!.%+>9PQ<Dbt@ns/3c/tPmRr85s+_X[-S]IN46m2E
%(Bg\P+Rn0NRh#RK]W^'`QSQ&%+244_`b2Kr'cMW$2<7372RRoks9r%ml+K,>F6g=`RW-L3!N
ed+!q\XrOA%9-TdOK"cICjblJA:Z&+slUe!+67%FnG-;Uc3<WZK23SM#urTWi2V?s(P:M:TcO
tj4rFSYDPA%DRZBkhjnKfn<ZhE"9;8aTGhuQGFSX]8P!,b'fDQg.JsV,hCe?pVGgGk?[T5#qR
E?FMcUg`KnfYXc9t8)!.l\"j\>RIW.R#[24uS4MAg9>?[$l[rFAN90tE1QQZ>4W$Om.9'b`"s
!!oT$SY5hTo!l&g\q2DHAPH#j9f]A3c[P%uKdK^Oec#RL"BDC3:gJ2YFjcF/j6Gq.I7XM*Mif
Z)#Lp+1C7<Wq^gGBX8EiFp#65<7TpA!P9NBU4/AU<C<6)34n?<$=orBP-RMN!!Am>bSIs-3Hb
FD,&VsOQd<'7+>rp>]8N-(9\peI%Q^Rqe2:9qQ;o^@h>[?CKLnn':F*d^-)pZh9o'_shcJ(r*
23!oW)k[.u`13pMG1F*@.EsL2-<)L]de+%jcA)jD"in&I$=m[\Rb!gmE6\%C>+sd5>N=2b]J&
`dXE<eFC)[Fq>4?dZO(]7M3_=-`eCi>?(9mA;Rj8F#t7OQi4r;X6hi#P&-TuJR\c5]`/NK`lN
Sa3GQhVI;-='eY-<95TER`lqjcR2W]*X;\D@Sfe!VK(em/dZ\3dE`'XC1ZnH]@$?'KYQ%Ip3h
b7Al;(bB0;O8ki_p6\`<nDUPt<21;mq/K'EaFFa(JVB3FXk9rk!P3]Um_#D5oS;/^'GU-:XD=
gJ*t8-o9(@tNu7npA%qi5OYp0<2He7GDa4D5S'Hep1@4:"at1CqkgZBG-9A^j9$(W.rXs1^VA
&8_$ih<`#>FUm@a4)W-GkgYH]TDf3]r7=BI*7`TD/k;.5dY_eSE!&c1&mUb4,)XMMV<^NQu8&
;Y2SB#;4(#!iVhrn\^m7m"5*Mc\[1P4ne@gu@5SMd?@XJ5]PeQ,O/Sc#1q-*3gnje>T:&7?/#
!<?(`W(ukA#/T3L$@]](D/3e^rdIu29\CHsq4/4i_g>K]$3\leNKRFsC2OdZ;b894'm1g&e7[
qkD$Y*"+09Vr!3l8boe,QK,W"[s%d?^]\Hqon7bbAW.^g4UFdNt3;hk902+j_TWY;G3?VIJV-
)dQ(oNp%4%':U)%@$]OHAr$o*WVki6$7[o,Y@O1hq_sm/"0bR4i),_0C+:aWg_)[6+'Bde?O"
i<#%8pl4QBGCJ"[/Cd_)omM!9--<BEp/:"La&k'WKB+C['LD,:$iIp<+o%XPO/1RTaWJVT5=%
u[l1G15k4p:Ys6qRFZ)\c88@!=h(38@)NN:=R/b@oXAhP<X$qb6/YWb6o5M[6=oX.mVRTsW?J
7El7A_%>OEKiOTI!2sj59pp6>]IZ`8)9s02\%SCF<*RarX'<]lRo@V\gKVJ`&6((u<6JN8NSW
Kq\;L-BA4GSl<`.=.%KSJM&cb1NK5)#C$SC>#GE6LC:H2UhPPcsOepEtXH[F^7We)_$$E@[@U
9<$JP-n^k>XaXc0a-,s8cSjV%]\o8mEu=<((%"]E@;k+]*a"1R.5OX7Fko_<11'u]J2b2^\RT
CpJduH\oQg\lDrI7U-8sciuu2b;??isFANF!jjf$4mgB9Km:]5Eh.YGZZf'jc#c]F%`-eB.*/
0bt=fSF\AS4t>!<<[1TDm]`U`m4hnDMKaIj:tdh@pEX;/![<]9cMoAZh-KC[@%tenl;)W8mbK
a0YJWDngbYW@B@t!1P$/c]ZD3nn]Ve(KWlJ__k2QHUi"3bkde@IREK(YG32Aa*JF)f(%WmIX[
jS2ed:Z6+-+]ocoIYG]KA!J@a_il?L>*n]\\-D=lbZe5b#grLQO5&HI?S3c@hHU(dHB2eDl'&
es65D`"JYjos:Ib#11m"^f;V`\KOba`ArC<6e*gl@8N1+5,NJmN9!lqsO1f.@9N%rc\nQjj3t
I__P4he(X?27JWs^2h1i<%):h.IoSS)"Fg"6O+#W@Zudo#TR&o35@mYSN.U.o<*9Zi/!jI;T\
Z%*I*SJ,31]':Co.&YRdoH6-Q.uMd\-G,^AE=[3g/UqT6L:4iSXT@rek2fX/M`"XG`NG7K)$Q
s1[G&rO"kf*Dm_rXKu1O3aMfN25kC]CS";L9R2T;+gmBKK+GjbRLBkTr;DlC'7PeHAp@%2J+#
?8[X8o%:G-TKG*[RSFX/J:7K(l[>rep`A)hDV?Pc]W'gYhr"[GndjbnUOn.o4$AeXB!<htWLR
?=\RU8jq3W!]O)#c`"VWo6e8j15EEn\>,#^&Rj:C&`!VnFj'B%#:J/c*!diBm"uG;AHUg=n/d
S'<8"KcgD=!YMEu$[[1mDTIQlA+K-nJUpd!Nd-XPWc#HS1a^!fu(PC]9M^P@#U>F`bL3n:3*Q
dhL1tU@@WM4k/QejbChHsr'[[2/ar7P9$n&2OnNA(E!:bD:*np*2,;]T1c<`%<Q?1R\%<DgfV
1\WeseYo5Ag5#[sZRW!KAUE+==$<LZ/-.\QTT]M/TXstQj_".]Hs#!nWfsuFm@QTo727\m-aa
XgeGK.nlAtu+HaFmL/$XL)K'GqMKrb3K#mgVt:gO!cE]a%O^8];BES<RU3ghMN5->0?Er1,.o
sODlf5<g\N0"n5S%A/?lM,LO2SY.'3W0i_a7dYlYB!Ia=AujjF#O(AW)A2>WY;t^m9dST*m-[
=*ou>+ij'n/)Md7Y<)GlO?U`LoCp2RdM?h\lSB6i[<E0&2<*=!5eHoO\p5f/Gb*"Sg?;FC'\U
mg\mDnoMDQdeOSPW$\<<YWaA\CB0-Zh6#?Og_.LB)hpq%2JD$`Z3eeFE'RXJ0Go[T@TuKnJZ1
JL+l,<<3Y1=aa,sa^"B0!^hJs-E'\<U(1Pt%,^lu5HfLf^+nrP<\UK/(0pn3fQS_DJgr8YW]H
P`g7C21n<`;GWoKLpYHFm(73-j=>5PP[3i_KTW<WSolI\HEef"cY:o.\g<@;n-gL%Q7rn@s5C
ZZ2dBnGVp;P_>NI(-O&_u'?%=&Fb1GgJWj[uTbMKBh,\0+d$AH8X+[m.h\+5Yu$'5uf:R4kp#
!qu9:N&E'9Kp%GgKgtR1en,@dHX/O=YmFG,dD/d1E5'o?)2ZXIh=\DTAa^"H2N$5u*K'MT7A(
YUp&(=bYOu!9BW6W0Fekm/]!C0ImlCb-j]&N+\h%,8_hg.0`3%q5-<DaitL]1UbPd?84r7c*0
<C%?""BD</W]Hhhg4"PA/Dt(Ce\!BsGf]>Gmn]LKMX(,oDB2_C'`\A:V@KUeU$LP6CENDj\O!
WF<RfnY?:B!cD7>O?AV038-#!>j<%1O<e]D(rp<MpK%);L/Dp8]jV5^2<IH33'X/O=ImFG.:<
)DsOT.sX/RfE_oX<jh1A<pnU0EcXKRYGUWU4-h;A*F$ej\e0;("N,fh)_Qf.KBaSbS=*"6;+W
_ZhkDgC>#Vcs7iMljKg>9o4ts\<!?8%&6,&JW9RoZBR;KBE)ip:n,8(bEW0d`>u1\)6']Cn<L
qA)D?'-uI*]%k@uZiS_L>BOrT!">UAi#*rL)V+J,&2t5ML#k;uo6\AbeVl-aXlJ+(kTqI(1oD
qWg^<r:9]bW5&!9h_ol.fhXSW[bDl%'3"ut:h<3a<@>.AgQNer:R?K$eh16,(%l5>hKKG/ljm
A`5IT=<no$mIl;86pc[B^5+K2TsTW/Z/_X5/j^i0#GlDpl$:[Pkn7<O&q[lo0:L'6%%'N?`5D
ZV&[ZF6F+P?Ho4^YXD\*.MUTl_8jujGbXho4,E"g"Q[1!"`+4?r5Cq/GJkQoV4W.I-m9XnpC`
42jRf>*Id\$q6AcLHEEqlVue*?;Qc[m'3a8[kPrTmo-!koEiZ.V(B__8G2)>lNbWE`lKI-V83
=)O^AoCT;M(RAP?EJ(Bg[EcZCEDEj);Qs[9Z;1Q9fZcD`;7pl2uG=!'tbhL:tU`82nM*h1DY%
Ajs-=mR@5`3VsBGY84153rZSB?L)`5lP`aW.7(A:K*WTuXu<))Us],&.uf=kcMHbfrON56S^8
!fs6]FBLB,(+LX;QA)H9QSJ(nhDrApru@-\-!!!oU*$ECeZ@:lEcCr<<RekrRCp>>YU5?*"9n
@4APWFAk,a4GLhXeRAE$E=)Xl5I?\V/_n><*t$[EE^DUWY8QqmGh?"-Op0KZARrBg2=NF<!?8
f'gPT$UL`$G+>9[R[boUeW9RnoCjY"Mi$k_*Nj%iY>=V[i'iY2:eTD,I?DA0fd_X"!b4+<%\c
c$(b_g:6Rg&TYf`Ccr?[2Heq"7k3cZ\'0Zs?KC;umP0B/U*nf25AXNl,Wfr:djA5uf;>@bXDH
o<hqSb:r[>l]L^$+8jmNlhK.Nqi\DrWhk2^HQu$*k9FUaLQCbt$E=)Xl<4W]db&k(lusFI;gp
q,n,#-L<Lq?KDLWNh?cfLGroLn7iV;)Dq[0cMBMcCqJ:P3gEh*h2`s*b9Jgu;D]&'+6CE1=2I
`EUS]Ig:n-6]g'LS1Z2=n1mOfupIk3^1",^:N\N&la(LYZC!K)j8h%cNpMD><ruh:gKPf)"#;
[IY/4/I/*.\S%6nVF]:;9qtRnS?l%\@.]VN=]BuZT/uY*,oir4;WEB@(!'tc'L*(,GVc6>O_=
k7p^CT@-K'O+MF[@UirCa%A_s1_Hea]p#p=4't<(m6p*fYpUGER;PH\*_tTXs!Qg1q[@%JtR<
1&Q71/jWJb[+a9Tl`3'1[bG[?<C-;;f5d/i5-IlXlO'WlK'M(.9@/@0IY0>D2Z3<T%RF)Bdrs
J_\(s*F)\uE%mS2NZf_8?A"V=X7DA5?[nqR+WZ![@shnc0!s0[lemC(beqr5'mWhk%o&(,1Wk
Nm!8?N<B7/OB&?d]hV!)8gq7lO[$<6>bVumD&-hIqEs$GJ7]Lr6"\OptEFAA,F]_Db*^\Nl"s
GQYIK<CSh6\90j:X:b@r0pq2T=l?ENk%!Q\f9cGFlBgG`He+QMlrgpHgG^A?5=*B>9cQ0Y,YQ
*XDs/k6AJ,&1I5MI![I1q3I'&&o[[YheRh3?iC+fGGJWhhH:20PTl8>h\RJ_c!PWfq/o`c(n:
8cJTL$*V7Y*ukb4HG_uE6e@?jmBp1hFb>;2Nh?_%W0TTFG39=7=nf:@C/EFe[=.)D^DIB7TA#
k$4o\adn86)%k7:p,qI^LK?Ts5)C\rjiUUi`W[97%[?U5Dl:gKQtTtE0^<I8ioW]Hi^Ds[2$h
TYpY0Fk;dpo"/Qn,jd-mp6O.Nj%i%C7/GL+F5X"s))H8HRu)s#c]C2lo"L./N<:K`bC"]9-5e
aOiI)A#?@<kgGaQXci1WH)D5QR7Hi4&iUGCCbO@R,kLK+3NiJaURb)PC&jD@Tp=i@L[=TlYTX
m8G:ms.mGH]*V`Y1$P^O*>e5uf;]p,["3hg:eQ"Lp8YmZASq:jDr_hJi7DUZ(^OcX0^n*ImCR
$E@le*M&Ga3=_iTam@#O,MeT4"B>FfFh'tMo0+),>BlV8[!Q"I^ONSH5uf;]p0)</)Zos:O[e
:'O6e7Qp&0dTYHRrBgYWFC^Y<s]2K8Nt"k@krdB/;?Nq%OtpGkN]&j[6t:gL_2ctoTgq`US2p
NJD?<SH-UTW/Z?HYp3hbl[gg.'1GF54YU@^2J#Mof%?f&%u62ouDRQ4\rqqo2j3()\c9?U;0g
_n%I,`_h+Sh5FrTl:^%D0<tSD-;F4uBR`EJdrd2;75uf;]p0)<_0mJ+Ihse>XiK:TD#ch[uof
GZ=7R"&L@Dfk:IMns]k552$n1Xg$$g5hsWe0O6YNI%g*n3]H8bKJAVud7)WsG`-Qc"%)F>UmF
lpZsi[_$6><@?8h3c9GnfhY9_!^)BA&mg&qjF[gGXrhGn&RL6"^)RWtId?o77o`BVr\a)'S;`
f58VR?AP$kj;m*eRUp8IPc)aI52UOoL@W9q"G50FMqBtYf!YO>0%lT^b$]RK77hYM9FnF5iNL
Vr#[)@d!rc>O#t$`X1LW3W4lWY9,oXgYt]4J)e%Q6F&mH>=."a0Q6Tou2U9iQ&E6L=aV`o0("
Os7q.gIb1f0:^$hbPpHQ5SP\'V\\6'8^oQt,,O\1?lha.81e24"=';*OQ#@I<!C0Im_*M'Ke+
Ph@^V9WLSqk#J>XMW<$a8SJ?@T4f:^r-\429?DSKXrg6pYtAG:*BB.Ou%03gmG.IJ]Z8U$L[(
s3^Q3+i)hY#ck6#F8Fo_Gl@.'+i)ClHF@`g;!g\;[I(R>!'umX"]_*igM=M$U%c2Tq-t]ZWj-
b:chXpEcL741$`X1LW3Y?SWfq//mA#/<3-lWHs&@*mlMI==4.aRHq6c6_TF-4B9%AQo:8[Ee-
i_2m!<:2:222)qqShV2.65/o;&*%2&6.>mTW/Z?HYp6Aja-]?5Q%Y6)$7JLHm5E%oV4Y4r)uT
j:^'*\A[?ug:8mQfh#<:giUGAmp+3f8iO*SQ@8Qp_:S6h%Id*u[YB<eJ<<*/%2Ck`kK\BbUm9
dCF%R7Lp*`0npCA4bbOj^H2llU:tXeWI`TR%IZeW0)n!!H<Q&la!/D6Mdh,$!-2Xk#m4Q[e1F
SDQ2AYA-lSrAtq^#5V1n]o'7&<tt^$Q/r6NSP7dR\%Tpae-Qd;3PXn7?K%Q'*!OeRK9:$.V#U
e$X=U=8K\F01gGbg`qWMcFci:D"kC8KG.i_NX,PM@olC%*<!!H;&(0#E3D;Y-URo2\'oI$Bb0
Rdlas&um5q&\(<<E7RK!!H;&(K>N4D;XRERoDfc]fUN\T0%#kf=\fV6+*,$DlRP%!.l]^$*$%
[[VsC`9rk"CIOoe.G<b<hYBbKFBDikL4&AWT5Z";A5uf;^p.a2r3W5B)nFMF)=%/Z6Oco<S*R
t=HeZ>e9Q1%KK"BF"c<-:NEhh:A]rfcdg%R7\8R8qb,M3Qlm_a!Vf>=WfJ5rG^Cg@G1KJ=t'-
K;q\Dm8`%-Y+kpLL]6dT=&Cb#;YorKg=AHhUUnONg/guP5Yu%Z5uf;]p8W$Q=&Ha+95iYQ.Vd
6s9#'r'In]aDNp7g@lCM`?!.l\s$*$%[[T@<mXfA=npHO(s+8jmNX*p4?qkaMH,ck=OV?.m=Z
IYZU<V/Y.mEZ5kpVXa!4eR7;j;f0V:`k,\l0CM3n,K+?;'H1p,HX,d`;g1D4S)'c,cS$:Gh6:
ChYd=:OBk:<)0tNPLXb5]r&+M@J+:5+L7g#p![+F>D*!iYU/oqGe(=Q%IdoYP2?[#G'`^N75o
!?rb;5:/8,r",Wf7:aJgpbP.[q5Rs4KX6B2De+rR9_`O*s[7X/J#l.K)K'q&cu-P))>,IGY$T
TSfDbLAB*K:CP!]oBiQV'.-WRXl&o#g5DU2!.l\P.]B)-B-O1%If$2"N1^LXJgu@%W1oSf,,N
mTrb^AKTF([N.Y9.KU9;o<4ZtFtm[nl^[Nh^PJ=qdm$B'*%:ToO\s5Z7@;2b4"M3J-C!"`*A<
+2bTkL[Ftps"m!?<,K!hI7ZT5nsA&<<Q<(C)(m\ad+EVM3J-C!'j@L:o35Qe.8RRB)5G%O4D#
F`#mL#"B>F5<"W)<WE%Gl-,Wr@dR"TrIJ$Ng>.YDH!C0IM:kb`G;;X!^RRg"H"TS[*5ug`M't
)I'.=LG>ITd[(;uo6\78O.fe-1-Pr"CN-iRQ7hB7_T5#c\01TSbe.[jEmLO,lYDMVn;+'.F6f
!$J3aW.HMaU:hdS)trfHr.?F"qh^/o"B>F5<"W(q'm1BoeCaM`84cV]!!H:)<E)iI=[c%@BaF
34T)Xh-PQXtd&6'6@5o"N^<RfZs+i&#G])VQ"J;KKn<<*S0&QD%2FWjc7(E`O?iP57;h_Epu?
kXsqWW40?,,di:nW;4>:f9`Q^5DcpRr9DJk3XO&*lkI6nf>])!(W+Gs8M;-Bo@Qm!!oS1W\>K
/qNXjk.m'E(U?5KRn,'"YNoq3Cs3&_=dTJqfUPY67ok1kiUnA%pJgu@%Wi3+Lr7fX%lA%mdWJ
XlTMAdG[h#$G^hE?-.V18<OT@5Cr<<*S0&QDUr:%eLJ\#H);XeM[aSW#&"9Xd]k,cCcpTSfBL
`N,q[%B+>I;.JXSPFi9bra8Qr2Na/q$35[XK-7+eMQ2QFlmcad4G.\>Uf?BhpB)a?&l\ls:dn
2L'ibuka]6iiL&c_ml-ErJ_?d.A+K-K_U5HNrrl!fsW.g!,Rn-+I"TUj=5nI!m79)d)_mbZ=D
g>@46:69uM3PAM5nsA&<<Q<$;<o,upIB[P\Q..r6\#j1D;).c$35Z-Jh!e!Wi/RmU)"XKSG9S
.qA6MG5nsA&<<Q<$;,pJ[?UZP-"P?+7Jgpa+WX,W'U8js%o[Qb9l(qEXM[fbGOcl@E!.l\P.]
TF)YG-L+A,jsGs8M?ieoKWeTem_jCa(/k'`\A:"B@@s3+Vu;s6"lp*`.>`'m3Choq1.@l<;Nk
^\RN6hfq=ls5Z8KBgEI6"B>S)WbWTY`^),]MYb%4W2ZMWWf!6G%KH0ppk'nk&l\ls:dn3WqGl
$bfZL:im]3(J\Vch5"Sc@&qVT`8"]YO6<"W),79)c.L[br6nZk%+\Y'90Jgu@%Wi2qrV&9?9S
I;Ft+K-K_U5Gt.$A'`-#cc'(lEG0>BJe#LfkC#`N4,@<p?R_YO),3(W1p;dJtNGNK'G+DlJXR
jgei#2N.UB7-3mR;<>BXdIA\PEJgpa+WmqBTh,ueOUVM17Y/UgKW1m>.gIC&'MMe&6!.sKj#L
t*$p&nAp;+p>J,9KrT78O-f6+-PT[2nY@4hct7UEdEk6\#>?<E)st&6&Zq:b?rhIItcRj!J?p
"$mZ%<)lm/;uo6\>t\!7rVRpPh\/9j<Rbb_;8;\dGH%;\VuhLB>)T&"+K/1q.d@PCU1RD&?i0
W-%DVNS5HPqLVuhLB\p6Sa4F'i;</l6(=d@3mqOs$qW1rES;8;VcB=/lc<<*S02_1herk&!#d
5\2EY[9](]RKJG'>kV.qj+-GCg99]<^g"W78O-f6$;4?l8KZArj[9C\4bL=f[Q!4W0Z1ds7CR
b4&JFH77C#V!'tbfK5,u1;m3N^#7IO_gXg>WrHUB'e'MH%<!62$5Z#]7XB21sh%E[iq[h]UIB
%3c79)cF:^$hbF^p&=2"Z"Y2CGT_#cau[^]$q$H!'r-<E'N/!C0K;fV"ZkXERo0IF2_uAosgZ
"BALil^rRFoAJ1t70Psl!!Lj+"P$#;Y^2Ei"B\K3e\:hS?QO[fUVHP;Gl%^jDqTYk3dqMY<E'
*$!'j@4'N@TWp/?S.Xe:Op^^K`,OUnId,,bPCK'G0Y[3_b\#k4"WW:.k=W2cd%WW7RBR_Aa+T
t_EGXGR@:.KBaSV$O)rTC7b+ksNVma+>dq!3;iGTF([NlI(9!11='>1g[%+@sOO?dJl*.<=An
7>SVBd+o\$>qgMOE"B>Fe:n?"mVB$=9eI^Y]<`'*oC^ok4l*YSiTF(\K3iJXodb.AFWV`009E
\?_JCdpmFWM,o!<>EndFapDTT4d-+)T_N?U<3R?r^/;;uo6\/QZ'1*`&Fc8R5*"TNZ3m_"VXN
n-@Q)"BZBR"B>F5<"W(ILVIK<n6N&m+K,?lTSfDb)NBC-Z[hgo<E'N/!C0IM:o-oSJ5oH4:^$
hb'g\,5$isBt"[Nk'"B>S)8hgJDXX!:870Psl!!H:)<QZuup`1S$;FLaT'`\A:"BF#9"F+0?4
]+WO5nsA&<<Q=E0EbJm'a.M:&6'6@.E)j+<E'N/!C0IM:hA&Rc)9G^gCW;5.dDqQIEV,oJ*Qf
\TF([N.Y9/!qnfD+*WGq3r5#:>o>;ffJ$pilf5A<Npm\abE,7g:"TUh'6'^.%bKp.Bo-(mk8/
VK1M@+qb!!oS1WiU=KE(:WX"B>F5<"W(YgCW<3<(-sV'`\A:"BET$"BZBR"B>F5<"W(Yh%3so
<"N"05YsmGV,Tg4<Dc%Y"TUh'6'X27!EMVm5nsA&<<Q;o1B^ep'a.M:&6'6@.ErF^hu:Ci2ob
t&<<*S0&QAc6<<,9\78O.!;uo6\78O.!<!?8%&6'6@!<cC&&6'6@!>&325YsmG"V=W65YsmG"
[Glf!'q>c'gPS!!!H:f<DWi1;uo6\78O.!;ultb'gWR":^$hb'gWR":^$h%<<Q;%5nsA&<@T(
i!E_JA2ZOu!,,bPKWW40?;H85-ci7Zc-PBgDrqqi6qn<(26'WnsdI2NkHge^thjr%<^uG<T5Q
@JhJ+U@&jN.')!!oS)!!!;)!!!!AVucr!+K,>A!.^^L!!%PBl6$',!$J3A!!%PB$31'VTF(Z!
!.l[#!!%U#!!!!)WW3#!#c[k)!$J3A!!".?!WW4NTF(Z!!"K&1!!%U#!!!!)WW3#!#c[k)!$J
3A!!".?!WW4NTF(Z!J=m5L!!%U#!!!"N.KBGK#c[k)!$J3A!!".?!WW4NTF(Z!J=m5L!!%U#!
!!"N.KBGK#c[k)!!oS)!!".?!WW3CVucr!J=m5L!!%U#!!!"N.KBGK#c[k)!!oS)!!".?!WW3
CVucr!J=m5L!.^^L!!!"N.KBGKJgpa#!!oS)!!".?!WW3CVucr!J=m5L!.^^L!!!"N.KBGKJg
pa#!!oS)!!!;)!!!!AVucr!+K,>A!.^^L!!!"N.KBGKJgpa#!!oS)!!!;)!!!!AVucr!+K,>A
!.^^L!!%PB$31&+Jgpa#!.l[#!!!;)!!!!AVucr!+K,>A!.^^L!!%PB$31&+Jgpa#!.l[#!!!
;)!!!!)WW3#!+K,>A!$J3A!!%PB$31&+Jgpa#!.l[#!!!;)!!!!)WW3#!+K,@WlG#G#NLc2TT
]NZ`J=m7RaW[T?E]XauN^kN#l7g31#/B;Km1B=a'qjDLBH.?`M7-nlg@KD+"kCm&^Xd;n)Xi>
Z!!H;PqLtQT,bU/b_1?)ol>m\A<]<(TNW,IVWrNF*!;-^`gEZGa(cZP08q4QY5tJ\ma_SU_?L
Q-0;`atE:^,ML&C=':5gSu!`;)G&K'H?1?Lq3:0kFk`aTXq+"lT%RE11nJ#DQ5Zk+%tG61q`W
YBrKYh1s\c!.l]9Ap4)V_0r;j#s9/GhYKNGCY.p\?T\gD2?Xis5o!c`48h=5rlUe<Ae7iFFZX
N`rR:p:J,p3\!B.:%IosbMUD4,G8')>"n\p1IA=8a'"hYkG\!rg-T<fZ=\$R"Q"BBuskiasXM
.opfbB%!uP!D&6_ItU$Hk1l$<niL@<)p'>A5WC5WW72*kT9t:a)X#u$)umsV^Kmch.Z3*>-E-
3qKEesLR'h$J=m6GrD%gVY4jnV,c'j@lus*HeX[U#ZZ$3BV02ulTF+N_%fSc@_7sq_8o[VClJ
QC%I](#2GE,nf0"BiFXXsPrVufr-F'm[u9hK^q>1*;Hc('28<"Y`BO)EeBf*+E9"k\KgI<_CE
X^b7dEtSuGm7u=.g.]aeNlOm3o!KhF"BBteG3i")TLp01L6I@q#")Zj+S=eNR<WX'!!oS)jmL
XUl-u'bI"\gZpSS;)-Gb$"\=C.n)?<&<TXl0?4[GufkN'3fKmPr32dBS;nU'<+KX:\BB\*4iW
W:T7d"dmaCWE4bkN"N\-_2\QmA].?`c5]>!S'^A!!H;P$?kY1-K6K13=,f=@Es>(k[)gBa7%.
?\T7-r!.l[cofDZgA@ShC;n:2sYfK^.dEKC9>E7U)itIFg\8b1B&6&\1d?3=UAp.<XG$YB:Wh
da?Tb"t-=Efe]ZX\+@rbDK:<S4A_hKE3OLQ+=?iC#d=N_*s196cN_8PT8$#K)4A.7&-Xk/T1t
)SN%s!?e=-[DU22cEH95n`Tbc6qX:<0B^/s\IAZ(G]KXV3d?fm:jTR/9lOF"C47/_U$]nS(BB
%:<3K6PN[E<p3%c/"c>QE8;p+\E<s$F[H[EU)l39Q@+W/pZ)%6]:3gS)=$bLLS!"`,'3ZYcuU
k:af43*B-`h.V.VXg=J:3:q+f)n0np,e?/\^-`o\;&&oauZj/#c^_'%U:e-4uc(>WIjEtTDu%
WI!6Qsd[d/hEA1,T2a,6nk;8S@CV3HdEI2kF/psMs+K.VL3cFCnLu:u_3D2.G?Dpe(O#G?7\d
SpF\=Ii]G4(^t+K.W;4)YAG0Z$R[VbU(Er&,)jeQp4L%;b2t;*3ZT>Q>=7U"gZum?F4LWqACP
a&*(jbAgqmg\HD_!rrV,;#O-pD1cRYr-A5:YEK8p`rCNQkJ"a&A=liK^9*@m%YDuJq"+*%L=0
V)b@Gkk78bSgS`BC7)%oLMhUcW=@KRaOJtQ;df6ih,Pkqo.7kaZ+a/))q14j6oAJ2"/9#tg;9
>NaYGEcq4"SW<hR@uI*Q2*IN_Q1MS*H..c:m:YJNhFOL\+.Lq&[.AdUgDUjb/sD"8b/G#9.j?
74,tG^JtQ;]f,Ia*c_G@S_2QHfX=s/nn;U^am'dpfhqaOB7_%U@<Ur4q8T9-[ntq-$@mLh:"k
=:,KaheS]>=520,]ajPPk/tZu7=)QN-LL6.7Ol5nsOQEkKu@0GG9^*rVVL$H(okKYR8C25*Zb
he57-pECZ-S5a/DU9ueH;nd]HPr]-"Y2dA'[I8PW4qFE\mjI!)B.;_^QcXGB1YM6J>1t*tJtQ
;=f=;V*mqlY&f8Kc>]AV_?A8E@K:$.UDnK(F4d)j!,o2J^A7>.<@Q#>=]'1VN!POG%%i-XfAA
\[VC^O\uL5YqVMFoAN8YXkTI-.&4Gm+79c*Sh154l0[p1uWAl6$58%he!R_qf;nj)ss7,IBPT
)pXH2&_M5Gbdn)>u8%5u"ZUWds6\^Ba<s:l)C)9j5@7IpV3LSk%>S[X<ahAQiK\Gqjh'S]Rdi
s8h-)fZ9f`+&Rr]<VHm8`i7B&%=D#+M<G::u?%(@XJR3tm"uKuY)2hIV6GR]W7Mn)s%]B_X4d
W_h<?g0S7/ojW[='@*h/4eZpOeI^DA,)]n!]=fE_O@DOD2s'iR:3d6`'i`e2D?Vsb<D]M;hk.
#a6G-_`3F6dCJ+%.#)V@>E[5['L%Kt=9[Y'd^Y%&ZSo(3Bs2rREDjZ'N"TK;=0o/mLpGWpakF
cqs?q@Lp@]2e?G9cI&mU?B"lL7h_MEsmRLCMn&LX-dT^#bgVe(D-mtrP)_a5=9p559IKdk<AR
Q?j,#k^KJ!DY3PZq4mW;;F[J3m#>9=>E;&.DU&f:hT\<OF;!i&uD!64ob<;l,\BS;ITE!.^rL
JSJAS?\BoJhWB=Yb"GocDZ'RnKM>kU4Z'0#F%OYC^N``;(_k<9sCX3K;l@D8ufGoo7Q@<]iH:
kSW2Gn%Y><%K5\<qILL;n5P`3F17>?K+:8^51@aPbGs=P<KW^((\G355r`U,_HD>kKC>Ykj9"
F<'N-TB9_M!EH0?Qp2k3;+,\RF<Ng$-Ydl0u\ai]6GJtSS/jhC52Ee6pF@J"ch$N+dSR[JDq0
>_Gl;6@euWl[!/NJ>751mIGK4l-]uOgOHA"[0;eb,X4frMnRUc>_7Q$`%"SHf6lM!P%<@Z*<i
(eTegbH.29u<69U<>d*FM*eJ,1?ft=iGR*sOSHbX@6.',\;,FrqnpF0D4O$>#eYJCJOjS`l?e
00YV@KP#Q<4JD5nAkjQCedhNu`S5**?6*ROu'(g'oA64IGWP4&*Eo]B1_Kl?VX+2dT<,rQT?N
M]"f<o6$YMEXum#OP,P@IT5rX77$U?^u)emonmSqK'H?TJ(@X5>f2[NL:OG\,!pN,cD'9RQU1
:kHd9A@#M"iU^_5Dq6.Far&?C#%\.DUC<M$r[[\FAU4i`8.D("[4%Q=5J1+7H5B[Z_?B8+Q?[
d?A$JS7,VqfS%u<N!Cj1o]'O4JR+J+8Z86j&S:\2[N"W1GP3\F67;UGM(T=Ik+hhafo]LfsYN
7jas._TN[[@`^+]2Q7I7qBfF;$fqM[ir-H]Kfg+Tl8lCX/$`]ofPfF)sUH-O)ZGT8ONDkGo=j
HWRS>S08ZF!=X-5d0EppKkp>)n(l,PG]oIWp^[@$V4XFQ&Nc[I9\u8J"i)<V##aVpe>\6ET!7
/#bLM1);?h8?NN52m%_!$jZ0rgq233`+u'T1'6\<UjGq%iuB/qMj.W)ak/8:8T6U,[bE=D:2B
L2p?T6.EcCAk4p+i7m)+qoK*`b,HAf:h&d;dg7'Q#9^9ed>WFU@c.9fVC^AGOaG@>CkbBXDo9
50'^kV5eeI4?1\*)<5:^r'hR_HFlthJU@4-Rn$G+_t,uS=o_?o6ZPQ:M1\&OV48?2/2etK'M'
NrP\0%ke^J<Nka9'jNfJOe\57oY%u9O[YNnKbkdf6i'*2SX;<$I#c^O3OG.<bV:P$E2ct:+YR
Nc;m9l?@P=]P-jrD.lBYU+.j11Ki<-ua5*j:$Ig@Gg=:RRcZ;j2C^'i`e*gmc-6Q\gnO7;ELE
kP2Zs=GDZ1[.1+B_dha(=+`72eXW@%5Br4eN/Ho7o-pUj\j<p%#Fj,gl)in4Kb`@+RN1A:Z3J
k;U;U%ko]kt`8\m**(p$<_9E'ERL<6l-_./2Fk<-7VZ8KV]*Db.mU[PJD3KE@s.c41SqXaU$Z
@F3m_mer<^H$Q\f?s3RL#42m>SelfK'LJsk-:u-+K-(RHf=J:o,8V+S_skGAVm#15ra-dd[<Y
<BD`t:0oht9&%="^?scS7QV$B&1`FZ2omGHs?XGT-Ecs9Js4p-"<uQ2u2nk9Xf(X1!DAW:CD$
O_$/NPBmW[T*6O>as2RV].gr!BC(BUl6h_.Ei#Rhbk7o=@W.Q@*]0'FB1<IU5f^_$u$-'!1OK
4m/bRF<(RtA;Ktk'OZ,@*bRRuCd5kU^6/JA4$uh-QmR't1Y9rucA0urAHhP_XZG>1ca.fAN]q
7)eeD)EUThCtZ/9G]=kF<c(YLdc:;jDI!gO4pG:WH87s2A?.V81O[0P6\;q"COml6c,q''DIi
M=Lbp:Dr]4OV?IMGSDA8^X1leP,V_o=1@OppTHIZScNJ0+V]`6Ql5ag2U@JH*JP53O0G8O1Hi
h*ed+g6l/tnSOYtg'lT8Ger*28fH9QNntci^$W@Qdpj9,(/DZGoNpYPQC<Cruq`4O[-_JL..A
-DH74->R3S4-Wqt(4ZeksjrG7)(8?H*US=md)GStZc\n/9-$5.g\Jr;KGJq2YGUp"DYjEof.S
fuXSna(`q*Lf/92Q?+LR0!fO=7,u[-\Y@\/dW#=(rr1_GR=M!;K"jD"jS+$7#k+MH[:KWDqt"
.9N[jPmP<ST5chCbgp7"M.c^>dQ_(85fc2/QLVS`UZ[e$PFQLm_9oVV#c<pKU,U*7:rjQF2[I
#^p$Boan=*DY72GLd(&lT>56UL-])^7!sSO6X5["dJ(@/o/_]gLXDHUN!MY'7`LFm@OX$9"Sk
f?C19/-P1E<Y7']HQ5>Q[L.<=;i-!%,+t"sneQLDGohd$e_Y#JOrVS?bh^PN%T*6%]oY7DImW
YDs^R+L/e=#@%$Wl&W$L+5!`QNm:L90!T"Fu4kqjZ\negl'g,T71bVmpZr3`u1o?!c^-\\u8=
h:/H'oHemO<;3sM$*&4@/mV:aU8;Q'UV'>n8r)_PID*oGYOc:n+d(1OGB<]<\<>V?=i1k:^Lp
_F.Cc#>4p`*NqHoLLs#4)/mf`jEW@I;_/KR?H!BZc^A5D#O!,2/6^KCp"X-E.dO&u)MK/])Hd
'3><)nXK4fW>U.?/*a<W-7b'\L4jg`4c),=:BZ4a%311mUj,?[-IX=16Z6ib3+"5c)d(*'m-&
E;\)P7_MUNm3j[*`&-R\^o&"Zf?^3\Hh=tGm[!h'Dq(.g)ke?s=(GG[7IbktD+K3T7ELQQXhL
=+6#W`<h=M=f<qWGodX;AE>r0hqG=1K+]<9Lu^Ih@UT:\ttX6+*6so$9)Z/\Re=l?RL5rM76J
L#F60@MFp+T?8oRCG'50m4.>/h4t/mrNGdapUs.>4Nn`)B!&F161o?Bgp"Ppk9[(tCsAb)h[I
!9Rr(7Pi0erolLF[i;RZ6e(\i:Nj=9o:6$6'!njc^'mK+HiXMFg6h>`lGa)4M'F\jof8&O=I;
`qhoS8I2%Sf.$+ME]NtQ?F3Pn7nf4?`kF,;P3]cG`ocIT0pXt55n6@p1T3Xo*P;#V+grtN9;L
c&mr&\S)X1RnXCqOXM/0P[J9[PR:c0FP/!==]R(<E0B_a3O1hcEq4jtVq#VV4a=sgX)(3_^8s
s@,:p=GN2oY_qr<62">Dp#;'af=0>bm<>3%4:.7hb<)]Q&m'II=;5n'(/*T7?BVhC7si20G`Y
Bp40@IJ@K=]0VQ`=H!4k<9JPEm&,5-mM>T2`suB>UZ12>*pW>WE`;Yi^I`Pm2ZO%&_-)BT_X?
NH3]aqX4N:*HrPR`#DJ/`k#LcG@&Y4u+_8i.VRX/SS?WQZAPIKo,ab2A<OEOJts/QdqrOD(Xk
e[#YD=[Y4SJ6\tZK?e,\'c=FcDLln,]MU94"A;W!'tbY2p?QeLZG,D=S?(T\Ff8`hD'c=I$Pb
r]3Ir7?GfofQ$[:D6$:TLnjfBn36Mq&dlp6C060#*[Zt*/hjNsNGLLYQU+kCU(haHBBEQMP'/
itTdS;K+)ncM(UPWW.^XiE7osrhHAuKprBCmkaWU5ZCkH;0^(Mk1V@,4Slj3NWGO(CF,6+,Qf
R]IeeG&i&8PLUh9L3RPqc;:"VPC?LnpaOb-_i4P?7;&9Q^A&Lj07PfH/%>)9r;Fh61Hh\\'WL
*!U'mCDdIqb"N`T>.D\[Mfk632N$Ldl*?=5iSo=h)4T2Y-I.VqfYX*j(`?C%Efi,elMptWR,l
C0H<d[gTk]9IJ]QYbD+pc(_C#c]D)UMWG2s#doR):[fT+me83=6Oqu7"O_dBA]b7k\Kb#DfUS
A/`g=<Vuf(TY.hpsJc25SHCWA#$*THZApib8o7j86*U$8DGK4+6HW43p_(hCTnoim8GuVU[9r
1OU;pF76I$dc=3%[2E)3m8W]9>E3QW\#u*b0-.h_bI#:gNl9k4&fQFj^;K>tf;M'!P6*&,dtP
WYBUT*Wso0cMldYO^8T8Xtk_=0C<*F,l$2k>TiAlSh@413E/"ar>3l3o)6Vl)Vn2Y=_19p>iR
5Y]rf;5bOPeVpu/L+SK-7!&:AEY%@0j>Y2o(p2YscQA5]6gRe^.eX$1BqPa-D:!!Lhp]G^DiF
[DjXH0Db(XZe!'X&N(nWCiaVfRGto&sR:Zr_'qk57*ck3FDc0NFM5.m8"QJF-h)HC!$Pt=o-V
(6^eXbj866qMmt/J"Ch,&;RXoN`sZ4aD)2O!#EE(Ag.!MAm7%']Wp=seoI#%e7R?^gZ-*RQ=^
!8hF$&?)C@_Y-&oIQH.TP"E@"hsX7>IWZ-NRqZ5c8Vdp[SQQ)4^o*>M:kSO+Z@FNf)Ub)Z9S0
dOC#Cg._0!3M2l$@im8%I7;]9=tMp&_m.q;(es[:46:[H-iD8UA"26I\g_YqHPBGkNaFBl7k#
tU7K<^ol[1MD:Y;jf15^q/E]Y0DpGe+N46MOe3[LGj$`TAtI1PVu=`Q0Fjj)J#@u?!+COW?g.
GnLM?jM-9j``=ug4.FgbmgWgNFH[@`r1QP(B?A-I?_%cD?PK_\rJ^:32Q=9hA:H"\V9(1H(<l
.a4h:$^PM:Y1T[$#\*r@s'T7N\i9PS?Is'&%qtandDXm\QPErSf:)Qf5]?c3\O7>Tbqt[,BQ]
8P3;7]B3&HIFJ\cPlZ:Y'Ad,qicc^AE>!40gNWs+Gg0)c,)ZgNO(*5T@HF4p,OuV/e5=V9W)N
6r.Y\8dd\'(X]q5P@c,SNVWe['[.U&935gd!^KRfB;[9I-Ko'hI3$AXj*G!QL<3giQA8V@#_t
9cR6Gdh:M]Tkh90/rF4E(in'&i@C5VJaY]=c$GW!_<hCE06h$=!HQ-K/u\M#^"C+r'N_([;ff
Zn\n0;RVH]O(@'="e6dm`kbPf$2ld-Q$PDU]U5gluWf;^_colF9QA3A&#1.b(bT"]1nnO_7fc
33`fr\l<MAJX2l7gaaU]c.Y+0aFhZoIU5>#$67Nr2k')sqejbAqp[VDRI'o-*BSFstI>;YC_r
*2$;uf4Ll?$b_^Z9<d<2f_Ag:dF6WP+)Q!;@jp<6'qD\&[=#9jT+^7?49O]$H's"BFU_+DN29
?S'+:MI0"0li+8!8=GVI5T.=to=i+q<*%Zfdmg8EK1c,<J]DFN\#3ImV?j3GqI.n!=YP50(Fs
qdK6WO=jGMm'O:"7p^Q0JbQ<-[2.,V/lHSq6dGgX+JFm7Xh-Q7Sc2f2r^Q:Wg9*J,asIirSr7
5]?2i<SRlnf.kJ+9AFVGB*Bu[ZaArfF>R8cIWV,"P%h+_oLH++2UVGP+Nh//:V[U:0nh1.r2P
Q-\<i/ICL=gMkp)G5"tj6'`]QX%P&/%O&m0e]1^Rq^.[2ba&UKUUoj#sm'DtIa+j``ojQR$>!
Ytjm[JU6DDaWO(MSf'#PY+X:A8,Y2?Qbk^;JfpXh#IQ8ScEo<m_+qP+[,%@,FP,FZf#7f5X5U
'fp`a^OGNfe#k_Z<s\9D6EE'I+K1Ue]-&'sF;"NL,W\ElqHL[,96At0Jb:.qYgRB!XC:RfCI<
\'Fo?pGMV`l1dIsfE3kk@*FQidiofK6\Q&Dbrl=Pg1UrqD/A1S,NS81KD.STiG3f&B$1Za74R
!,kU!7q&gerIJ>ipX+]Wp4%DbANNUNAp<-%J:W<gd9P9I:CA%`tUh)7=@HSd`%)M6T=e02];L
Gp\NZ,pAgH=HT:p5l_eRVDEOK+rcH9.B03&d/_Z5+?MaB*f>q8c[;]LorB&/:dibSeVkA>Vr6
;R,I1E"7G2W9#:kJ/pWrh0e:G0(.Eu8N,nhbK,Mn?e.8QW_3L2Jga8/PH53?`OtY^S`e.W]tc
m51+f%K4,#?Gf-m!8;\/B_Ae)&%21[$`c9K9U)fQL>QF1N.']Db(kQu9>"r$Fi!,ml:\fF,BY
ccpFHZY*QJm\PraDn[\=;Uh4/nSMs^rVg>/l>Co%W?Bq==k%=d42g1BC#C>O0emA/KA(A++*r
E\3`CaSln?R=7CZ(miLIZfX&lQr6CItc3k\+/VO8BhIEWKRor+$D1H@L<C@<96aq%%e%6^3g0
.l*RbG0JH&)*L"Wn5&C/IrSV#&4(5NPkH$JYG?EXl>E3-kcg>VSlqf@738UHjl:TbrepX5.X.
"#e\Hof/Ac'.NAu6VV9Y!"=(P4-LpY#MEG6R^/=fR3:g06PY`.;DrqXYG'X#</S-(SIQ[6!L:
U1ffKj^RPP@p&#;gJ?,H@J'0iUuHWbr:aWE:6Vp7$q<cM=W\[r<2mm(^jaFka5%':EuF@0rZ^
$94=SY6[Y(X#7ug.ec<73.Z[E)QRGF*Em6dJ8Ve-W*qZVGHT=8\tV)c!iH':iI_k76+Q2De@P
ZMgD@\Bn+Jh#=H&ie2S+u@;D-T/I/A!$4BJd7Lngg`4UkBKtgS;!5cWuA\>Xl,q2>9(e2Njb]
tC68f'Rjg.s4rE*Qb4BtKS=auM5%i83oB(`*cG!dMom(3sID6HeOpJ(`^Ie,Gb^e;cS7Xsf;b
bi)HsgOaNZl1Pl#[=BVl\Bn$Tis\21+`fX-b&rREn[c3gEha>AnP2a2QWma(s,'#2;fKgQ/,=
[O6a,iM7#'>]?aoB@r`pIlHEdikh7Z9$/)b4(Yos:H3qu]RO-OVc$$Y>3@O9ghk[4oj=e0h+]
<fB6QQbfO$4U/_\8(pKKZTS.up<'+?,ZrDWX,LMO_47H\"7>>QX-NH6#O;/4]sJr79dHTM%h4
E&JXG^o,+>r;A;8cj/6/@[-,Z!QqW4Nm'V7I/qCnj_47ZTT9(>PpS[2B;"O%/i'#6r52mNH8E
J$@8@%n(Yak%NVZJ&3EKFKtV"4n89r(J*C`D<o=gc($Q.E#/:BqU3h3U/,5S=C!4jKgNLJ]aH
OrPe9b/Y$Z>q(H)h&`48)lu,s/\Wfl`ef<M$sFY3S'H#?:I]gC-+VWi>+GLifEhr-Hc];to]Q
H<+&=h*W4?"'=gPIg*`MYCcR(_HD>kK?pmYjR[.7q@:)Y&+[T`a+`OsW:KiqEj%5#Q$UatRAc
pg+gmq"N%_/2'V7n(-HGK$"FfQaXgX[a1SN.TdSX5b^,s/icMct$>M".*aSE=W<!?:Mh]1D%4
bLnjDu4[k^Tet+F['BN\9#/YoA^SrK>,j$W7bh'>3?,^DB\6K[jE*Um+Y+o1q@qFNPTlS<"W)
rrT6)<qkP90iV0E,[ITiSYVLHlZX5\;h48'MnsJ29ha-[QUQ1u.6iAZ(eT\Tt8q*\;[Zc#&L#
0/D?IkpJkG/jKJ(cI#+]1OQo9aXUZV/QtIGZcYF^)@)CJ[aV^$[6)?+gP>SPMOod1*=XK)h0^
^P;JBhE!![lXW]%B.KF`mb%&ViuY]hK"b`HrYIG,#KLDfk;VX@S4E<M(SMiWWXEa("-\$rA_s
Vg^(<mWZ6h3V*Xm*IH-k%#1@b?MfW[:6&@D7n@oCK.YT*8Qf,dnd;*Ub'n6Gi.'igm^K'GZAA
':Yh:oX3US^)WIcH/r2iHnG#2(-2g@rpqlC\5B?;&a0QZRN(@W$]jR3dO!'n.qd,/d<-7"kAk
pb%$W]5\8fUHU:IVcc^IY.X1NQgN3:a*1Lp@hZrP<%<(^+Ye<+F[;5qXd:_=iJndnK*Me\#9P
0,>,"PO9=i7mSa$S7j9^gT;icORTPifX6(*1+*FTbB!n[tXh@)N'A?e"$3LDT)jK@%34TR%T3
k.Q`PG"i/hW331RFmPJ\WSan-n(1I/QS;Ybk3NlpofI-jSfORVpL$q;cgqgjUfQZ-/"38I0=Y
uK?,Q8J7aL72_K.[+SY3R"2bM_:g7,<r-^gPebC4Jca;T<-S1g%VC/ZS-c*5906.*ol@p=uNZ
X[OV2!W`nC-+&U3rdOWg^\dVZA.O`>4e,FPd]n)9Mf"u_`X=KI^`ii5ga;G0/R!;kkfL@R[I_
il+*3AF*_j]mie&,bFARsa6Cs!f[QRb\"h:@8c>in$#<UK-D*#JNc41.I4#s(gJ!(QRqDBW7C
J&ODgs`Thq]K?J8)?Al6>(9h.a&t7ort+UMW*7RS+t7J]5B2O%m8ag2h>)2hWgi?gV6gE%g>E
Gg!@>2EZ:])e6e_?i:''mmWj)n^8Q=[W1N`Fdu*MhKP\u7J;=Mdg"?V[#(_J>,5hS:uigY2Ck
^YiXJh2VTRh@c3dfF\MPNJ/H#Hm@3VPrSt#?8$Md`,Xcn/.T8]i/Bq<`2g`AJAc\AqOCL_0g4
275XrtTtfm&"UV&)KB;Cm=P(hdi;PBnP]Fg-g%&YZKb$Se\q/<LX_&kC(619KT4Dn0Ycnfr&%
r#Q[csrH`7BRF7[r\-dHs>qtaO+m^A^Ed\f6"n"F;D]I*;=XC%Es/T)fGC#HBe4^2RXS&*-U[
O"N[/FlsTK7:dLi0]3..B1m7JGDG"k?%bXEG!L:3`W4.VHM;'ieB2HWHE2gukRKSYO4Srf;(`
+!68#\Y/]h(gX\+KFMhV44Eo<U@3WFrn!S;="2JkhPA7)B+1e][tuN3Skb[op9e$hF]iXOWUG
%hDZ2lBfOm:U.9d#Z(A!!7BA)T1/u:[+j%1SXOt5]#=neF5SX-F=AEIk?YHSt_aJQB6c4'ZT0
HbIYp:CV`P*q--4Q#%?P=CB3q])fF9gfXPSko-N=(r=6BsWEV1>Y"BdrkkgE8/YDZMi^YkoIe
_(@lok=iu75[J+Wrgs@ca_qOk($klbb9r_Yk!P%jt]9h`/?UZ2Q[O24.ptjPlA[[Gk^bhE8Yu
ao+)GI`hWm(mNo=Sf2;jNX#Sat$KP;.F9>r$,M.s\A/p[#^I6cG^mmJX!)ncr"-[N/-Zeh?fF
(MW29-BHc=[N@T^V)dGRd:_-0cFu5GV(r@=f1DfYCRK#`=OCW?0g)r\/Rd,UAd-^r]kPbJeib
$I>%BU+V"[/?m735dFdun)?ZoY6$QImX%u_W="5EKle2]0ER:S4C?C"M+F\6ejpSPJL&M=#"c
?%?=G+2%>@mBaXa%;X\LiUC#dEc<><`#@MNRQ1WPOj,_Gr(IMlQtAcW3YK-I$b<Q]M9sTh.3=
s<_iPZAr64uAaFUPFJ?[FT?$\r,l:gn(NV3l$IS8]YP67;88@erDS%9c%;aXKS.>EfcL5U=UY
3NQT<k2HE1JkfPdR%Mlf]=t$=(Z^Me7\#=_4'n!pX&`qn,S1D&%F<D,sJ=q&?Iml0;V4Ut@5a
/>F4,"Wq]9,RE6s+/XB&6+*%6P2J)AW8=E<G8.\+iXbTdn3qDh1MWU>j6JV6%!?lgmg,qTg:'
+8g"m.OhsM3d.Y#0V-_8.T[#*jqiLVqXW)i#>F#N93U#aHuB]_"9ZONM(HmfJV5e(/Dn7Aa'(
:E89\/H7pP8P]Ih;)W!qk2*$(64FZ<L>87SiA@Pq#/R1<0`B-(tj,g[#&q6$#N^>?,rGoYu?+
DZd42L<EW5s$U<"@$@FPic!2'>a4goMmigl29R,H.5M>cT*ZC5ABHNsOs-cm#IR05[#?BY/eG
9&^4_Z>ar@`#^9Pm+c'i\95L1j<h$-@XodnC5O"l%p81q^;_dnUu39u)q_GUFB`#C2L;7)Rt2
]f-G`WN&GH>#7XaL&/G(*[\!`T<,KZegkU3'Q$1+'i\95L1j@$Jea882jk;:Ck%4=baR-61Aj
7G4g<aMgNAW9]i'IIG0[hH-lhuZ49iK5fA2&d^ZV*Vb`Ihm217-b-=*iIhCl@(F4)DXcmH,&6
$42dMX]K<PA$iO_g!T+V))4mqn"D*mrL<RG#G:+7d[W%N!_Ntn@UfGL(HlPLJtkCcOj-'F+/]
4QK4jWh]G`l1UP\hpQ@lQ^Agt!7]IaJpg)Ea4\BRcghfBI'i`d&'(T9Hm`UdIi*FjX\iHW+,2
7?`JaHn8]=fC5!hu@A/$OMIerKV/K5,ai@H=/uh\XuL<C%@W]a)!?n%Z3!n%8HgUO^]<Zro\;
e(tY\7eW:Om=n'^=\Ust/?<i^g^Eifc1&>Fn9I_I<0*d:\$Lg^\hbMncbkGd(AYZ\<2js9hoY
\3)[%BgcJ=\a9pD>GBX<:?kccZ_$q7Ms4qnHf1Bc7RJq@`E]3rP6o3:W["[Glfb2-hA/"W:XF
GTC[:2uuL^_RJ\\#4JBf6*PT2n=^?4j>]jUX$VWIfU*[J^SaGqocS85,_F%7XsT;b2@PD@/lE
NmSU+*3i^:V]o@aS):hjVoC[@cd7)L'[hnPDJgpbP.T#uen5YUY8nWD(ZZ'%*G_qmQIb99%Jn
gF)S%<Yl:UAG727Xh.,3.OGHco][18$g6DCHFun1a;BrKNt$m'm-?VugPr'VEZk%r&kAfo(<.
<:k)t61pqehn5Ab6<&T1H54X8\<R3KE&f#H=dJ6&_Kdu5j%ciW18okEcgc5=T\=D`!>&4]Z?;
2:UIo0;_Ysd3KkDcCqd/i<pM$2_k^Ln&qc0Q)k;90hLASFA#j]A;4NFRKLi3o`#"=;VZ]ap%S
i8bqH*7_@4_H4e-lN!nJ=m76Z@dN?cN5!iaJ9/a(0!ZU.?>,p7rt%2A;?A')lEhhZ^g3.3DTl
DASIW;9JR=;2gk"@YkE,McAm=@Zesg(A:loAem[(bpRD<c"BD+RS`HndM3c2/(E_8jMUt13AH
^BW8b\l)e\1`AabuBkgr\2e2qVb%)ReBN\k[&5\+]!aaB&)K?d--*/.4HKiM_LIK[Bn8GqZ*a
TsuusAcNBAJa.EG:SM:5nUf2%)8ga3)>g&%K[5F4a1o_&WXh,)pUL0Dek(Ej_K3=9kPIqL/_,
-63$KK64hET3hs51N:j2mB<FBl0cL#"RN0?hKDC1XnG)G*h^R^>^g@=[MZuo?3b%EZ]Sp/c>U
nV,+a^p(>,,h[5*&N;+0G>g*MUj(kchKG7YoFDWJh"Pk3q/]7'0Il1mtDM2PF<KOe$95/i8V[
T0GOKXnH)>!+F"a)8(pW8IqOL-[p$UXL!SpE\7i0*j^T?-e'=]r._@JXe*C#J[fAZi"U*B/s'
@[\o"51IG:+6iI9FGMG7[LhPQ\jPg3q.)O)Yk>J@J=a(].Z>\4jd-Bf)nSlhRocG`Bu3^@%a&
qsQ/shU:IEe>B>M+K,>m/#_=+i:!5?o'`^VfJ]LIB.lmNr1;,_)[=D0@,F\)ma6HTf3tUNL3d
2r!HpE^EOLKb3Y&k#.H0f?`h7W3:%4,8+3\`mLXsfU5YqWO5H*G@i9u@me3%RBZ0`=/9!7-`[
A-lpRjn7$k<8QQq3>:3>.rMkQ:X-*1aG2PN,+lTH90<iOm'@2c?O_@Fe%D/!'q?-).Df="b3^
ULF##[f!-f$:eds<@<HTTBA`##KZ5f@DahQl&#M>Lq^MF7$9m$<dUm^#GeLeLje/p7c[3s3&3
oYe"+[$O:qSTt'a9ngbetGPc*P09a0ccoS%U@U:^nqOpG5!&-OP@J$2aJgmY-[U8=qR1>RYY=
>ahHEj53!WOV.YG._ojd,AYQRgLXDHUJS791]KqfP+2bE8\69oI[?7QiYHctE&d</Jc3pc_K!
^Pl(\Eqeoj.^dfc4Ts.(&-DHOk@opGo4TF+Ms,J>n,_qnYXhsPAs[4.Q#k:WatF\<KL_eO+6!
KV4t@/luM!&dd0@sm725Au6?]&0kZjo0H[rlqs1g\.$;J=m6Gr\1f#/O?\M+g5ZC]"bM@r;:#
m:mb5T\iKJJM[?^BRke)2:n?l+;C[sD.JpJ-Wr2V5%)pI/SnC%+oOWUPHOI>JojHXMeGp_j!j
!d!h%lD@VdchY$oqt:c_h5Pa&1d>F"qOYO+)T0TK8T!W4$car`R6hV>&G>-_hj--Nu+Z%-MJo
;)l"5.KG&M5_VP\8QjX]Sal@ma$Y;g%B@P=KTkpG7b`*\0[uT_\NVPeW'7#2ngT1U:4^dE9rY
?,VO;rb\f\L>`H1Cld2'T-d<ja=!!oS)eHpC\e'&_7o%11:G>I4C_P.p"lIht0(JTe:Rc:ULo
2bd`a!bthl>bZDW]@i'Pqpb8@#EjV.seC4oU68%4>*a9Y"K0'Jh"Rq"5Zc&L]8\7kMui^?q>6
\L1>:sZVNN\l8mn/YNDD".XI&C!rI`finG@MhEd9t_\9n"]AV_q;b]D2gFiPY.R:ColG:-VUm
0dpS4/_%Xa,P61i)GXc@4q4<`Dkid'l0Ul^mArU3i'8dC-/fEi>N8O)[,GqPI,_DAN_g#;`fB
AoM\Y@$sYM!J$gMYhYo'YA2*AV94"LZ!X]uXL$%Jm7@rk75G?JH]RH81fX9m6MS-N6Y,a)%n.
fpMMB#443tb/m8%u`2q&!&.*T.Vp,SRR:"Y'biQV0<!'q?m\j84?g`KV]H,o6"?K^[%'b>Ra?
M@/`"njo/>U@4h+07?21W/fKMaI,Ob1``i5pc/J_Xi/r=E8"(W`C08#j.\:kIVI^lY5caD<6J
ln\p3$8Fel9,t6?gePlMO<Ifs^eUEc1<D'9M[o&E02eW0[?IE-kBWa+BlBD*0PM^Y-)pBj\1@
+I&K&9;F&hs8tR@VPFbK4b6Lh8a*Isb#5s6i[^1.FQPOAn3/;:l;pmf&HSodU6rLWRkcPOgO8
Nq;raD5(&'@I*t:Vuf*KjR60LWgZhF4I`STG07Chh44H4KAc_G;#?/Qs"l$8T&m'$H<2@+-Kj
iH_W,_bKY/Mp`qF&UIl&HJ&#2a9GMW]Q5o=c`.KG&M^]oMCX/]-!P@2oN1^j<.E>".PEq\7U0
N<0JW2e]*i`HAJ)4`&!Y?Q*Lh3?N9&3Rt[P`n5s,XZR`Of9BLkOJ;@a$3\QnS8lM<u1i><Ij?
<eZe>kXmpDp9U^AfW^%Y@5ANJrf>0VQQ!Fn;!!H;PoFCn@0RU0+dpiq!`SJYgB/abb<n;G&U$
\3I+K,?XB#jp$\0%u!eZ!LsWLSAH(4!)51S:^eM&tg\!'q?-K00+lN4PoEI-hS[N_Ph&aW2GH
9$UG_/AD/jWW;\u!P:XolF9<e]00k+T'61')tub'm9G@1s"27o!'q?m5%4,e:0#3qrm[-FB&U
X@:"!5HC$k(T8-M7T"fPiPfL[Po)]o8Rs"4\\,<AM1R&rer0CcSf-0Iol"[Glf?t4gb1TI$1j
#@&>Jgpa#!!oS)!!!;)!!!!AVucr!+K,>A!.^^L!!%PB$31&+Jgpa#!.l[#!!'+ArstHS$:;W
Ta9_hH!!#SZ:.26O@"J
ASCII85End
End
